"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const angular_config_1 = require("../utils/angular-config");
const package_config_1 = require("../utils/package-config");
function addTangramToPackageJson() {
    return (tree) => {
        package_config_1.addPackageToDependenciesNode(tree, '@ng-tangram/components', 'latest');
        package_config_1.addPackageToDependenciesNode(tree, '@ng-tangram/pro', 'latest');
        return tree;
    };
}
/** 增加 ngxs  */
function addNgxsToPackageJson() {
    return (tree) => {
        // Add Dependencies
        package_config_1.addPackageToDependenciesNode(tree, "@ngxs/form-plugin", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@ngxs/logger-plugin", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@ngxs/router-plugin", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@ngxs/storage-plugin", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@ngxs/store", "latest");
        // Add Development Dependencies
        package_config_1.addPackageToDevDependenciesNode(tree, "@ngxs/devtools-plugin", "latest");
        return tree;
    };
}
function addFontAwesomeToPackageJson() {
    return (tree) => {
        package_config_1.addPackageToDependenciesNode(tree, "@fortawesome/angular-fontawesome", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@fortawesome/fontawesome-free", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@fortawesome/free-brands-svg-icons", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@fortawesome/free-regular-svg-icons", "latest");
        package_config_1.addPackageToDependenciesNode(tree, "@fortawesome/free-solid-svg-icons", "latest");
        return tree;
    };
}
function addUniversalPackageToPackageJson() {
    return (tree) => {
        package_config_1.addPackageToDependenciesNode(tree, '@nguniversal/common', 'latest');
        package_config_1.addPackageToDependenciesNode(tree, '@nguniversal/express-engine', 'latest');
        package_config_1.addPackageToDependenciesNode(tree, '@gorniv/ngx-universal', 'latest');
        return tree;
    };
}
function addFoundationPackageToPackageJson() {
    return (tree) => {
        package_config_1.addPackageToDependenciesNode(tree, 'foundation-sites', 'latest');
        return tree;
    };
}
function ngAdd(options) {
    return (tree) => {
        const workspace = angular_config_1.getWorkspace(tree);
        if (!options.project) {
            options.project = angular_config_1.getDefaultAngularAppName(workspace);
        }
        const project = workspace.projects[options.project];
        if (project.projectType !== 'application') {
            throw new schematics_1.SchematicsException(`Add requires a project type of "application".`);
        }
        const mergedRules = [
            addFoundationPackageToPackageJson(),
            addTangramToPackageJson(),
            addNgxsToPackageJson(),
            addFontAwesomeToPackageJson(),
        ];
        if (options.ssr) {
            mergedRules.push(addUniversalPackageToPackageJson());
        }
        return schematics_1.chain(mergedRules);
    };
}
exports.default = ngAdd;
//# sourceMappingURL=index.js.map